@@ -16,7 +16,7 @@ CONFIG = {
         'license': 'MIT',
         'keywords': ['build', 'hatch', 'packaging'],
         'classifiers': [
-            'Development Status :: 4 - Beta',
+            'Development Status :: 5 - Production/Stable',
             'Intended Audience :: Developers',
             'License :: OSI Approved :: MIT License',
             'Natural Language :: English',
